@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -35,16 +35,16 @@ import org.apache.commons.text.matcher.StringMatcherFactory;
  * {@link java.util.StringTokenizer StringTokenizer}, however it offers much more control and flexibility including
  * implementing the {@code ListIterator} interface. By default, it is set up like {@code StringTokenizer}.
  * <p>
- * The input String is split into a number of <i>tokens</i>. Each token is separated from the next String by a
- * <i>delimiter</i>. One or more delimiter characters must be specified.
+ * The input String is split into a number of <em>tokens</em>. Each token is separated from the next String by a
+ * <em>delimiter</em>. One or more delimiter characters must be specified.
  * <p>
- * Each token may be surrounded by quotes. The <i>quote</i> matcher specifies the quote character(s). A quote may be
+ * Each token may be surrounded by quotes. The <em>quote</em> matcher specifies the quote character(s). A quote may be
  * escaped within a quoted section by duplicating itself.
  * <p>
- * Between each token and the delimiter are potentially characters that need trimming. The <i>trimmer</i> matcher
+ * Between each token and the delimiter are potentially characters that need trimming. The <em>trimmer</em> matcher
  * specifies these characters. One usage might be to trim whitespace characters.
  * <p>
- * At any point outside the quotes there might potentially be invalid characters. The <i>ignored</i> matcher specifies
+ * At any point outside the quotes there might potentially be invalid characters. The <em>ignored</em> matcher specifies
  * these characters to be removed. One usage might be to remove new line characters.
  * <p>
  * Empty tokens may be removed or returned as null.
@@ -94,28 +94,26 @@ import org.apache.commons.text.matcher.StringMatcherFactory;
 public class StringTokenizer implements ListIterator<String>, Cloneable {
 
     /** Comma separated values tokenizer internal variable. */
-    private static final StringTokenizer CSV_TOKENIZER_PROTOTYPE;
+    // @formatter:off
+    private static final StringTokenizer CSV_TOKENIZER_PROTOTYPE = new StringTokenizer()
+            .setDelimiterMatcher(StringMatcherFactory.INSTANCE.commaMatcher())
+            .setQuoteMatcher(StringMatcherFactory.INSTANCE.doubleQuoteMatcher())
+            .setIgnoredMatcher(StringMatcherFactory.INSTANCE.noneMatcher())
+            .setTrimmerMatcher(StringMatcherFactory.INSTANCE.trimMatcher())
+            .setEmptyTokenAsNull(false)
+            .setIgnoreEmptyTokens(false);
+    // @formatter:on
 
     /** Tab separated values tokenizer internal variable. */
-    private static final StringTokenizer TSV_TOKENIZER_PROTOTYPE;
-
-    static {
-        CSV_TOKENIZER_PROTOTYPE = new StringTokenizer();
-        CSV_TOKENIZER_PROTOTYPE.setDelimiterMatcher(StringMatcherFactory.INSTANCE.commaMatcher());
-        CSV_TOKENIZER_PROTOTYPE.setQuoteMatcher(StringMatcherFactory.INSTANCE.doubleQuoteMatcher());
-        CSV_TOKENIZER_PROTOTYPE.setIgnoredMatcher(StringMatcherFactory.INSTANCE.noneMatcher());
-        CSV_TOKENIZER_PROTOTYPE.setTrimmerMatcher(StringMatcherFactory.INSTANCE.trimMatcher());
-        CSV_TOKENIZER_PROTOTYPE.setEmptyTokenAsNull(false);
-        CSV_TOKENIZER_PROTOTYPE.setIgnoreEmptyTokens(false);
-
-        TSV_TOKENIZER_PROTOTYPE = new StringTokenizer();
-        TSV_TOKENIZER_PROTOTYPE.setDelimiterMatcher(StringMatcherFactory.INSTANCE.tabMatcher());
-        TSV_TOKENIZER_PROTOTYPE.setQuoteMatcher(StringMatcherFactory.INSTANCE.doubleQuoteMatcher());
-        TSV_TOKENIZER_PROTOTYPE.setIgnoredMatcher(StringMatcherFactory.INSTANCE.noneMatcher());
-        TSV_TOKENIZER_PROTOTYPE.setTrimmerMatcher(StringMatcherFactory.INSTANCE.trimMatcher());
-        TSV_TOKENIZER_PROTOTYPE.setEmptyTokenAsNull(false);
-        TSV_TOKENIZER_PROTOTYPE.setIgnoreEmptyTokens(false);
-    }
+    // @formatter:off
+    private static final StringTokenizer TSV_TOKENIZER_PROTOTYPE = new StringTokenizer()
+            .setDelimiterMatcher(StringMatcherFactory.INSTANCE.tabMatcher())
+            .setQuoteMatcher(StringMatcherFactory.INSTANCE.doubleQuoteMatcher())
+            .setIgnoredMatcher(StringMatcherFactory.INSTANCE.noneMatcher())
+            .setTrimmerMatcher(StringMatcherFactory.INSTANCE.trimMatcher())
+            .setEmptyTokenAsNull(false)
+            .setIgnoreEmptyTokens(false);
+    // @formatter:on
 
     /**
      * Returns a clone of {@code CSV_TOKENIZER_PROTOTYPE}.
@@ -554,11 +552,11 @@ public class StringTokenizer implements ListIterator<String>, Cloneable {
     /**
      * Gets a copy of the full token list as an independent modifiable list.
      *
-     * @return The tokens as a String array
+     * @return The tokens as a String list
      */
     public List<String> getTokenList() {
         checkTokenized();
-        return Arrays.asList(tokens);
+        return new ArrayList<>(Arrays.asList(tokens));
     }
 
     /**
@@ -1036,7 +1034,7 @@ public class StringTokenizer implements ListIterator<String>, Cloneable {
     }
 
     /**
-     * Set the quote matcher to use.
+     * Sets the quote matcher to use.
      * <p>
      * The quote character is used to wrap data between the tokens. This enables delimiters to be entered as data.
      * </p>
