@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -42,9 +42,8 @@ import org.junit.jupiter.api.Test;
  * <p>
  * This code has been adapted from Apache Commons Lang 3.5.
  * </p>
- *
  */
-public class StringEscapeUtilsTest {
+class StringEscapeUtilsTest {
     private static final String FOO = "foo";
 
     private static final String[][] HTML_ESCAPES = {
@@ -80,14 +79,12 @@ public class StringEscapeUtilsTest {
         assertUnescapeJava(unescaped, original, null);
     }
 
-    private void assertUnescapeJava(final String unescaped, final String original, final String message)
-            throws IOException {
+    private void assertUnescapeJava(final String unescaped, final String original, final String message) throws IOException {
         final String actual = StringEscapeUtils.unescapeJava(original);
 
-        assertEquals(unescaped, actual, "unescape(String) failed"
-                        + (message == null ? "" : ": " + message)
-                        + ": expected '" + StringEscapeUtils.escapeJava(unescaped)
-                        // we escape this so we can see it in the error message
+        assertEquals(unescaped, actual,
+                "unescape(String) failed" + (message == null ? "" : ": " + message) + ": expected '" + StringEscapeUtils.escapeJava(unescaped)
+                // we escape this so we can see it in the error message
                         + "' actual '" + StringEscapeUtils.escapeJava(actual) + "'");
 
         final StringWriter writer = new StringWriter();
@@ -95,35 +92,26 @@ public class StringEscapeUtilsTest {
         assertEquals(unescaped, writer.toString());
     }
 
-    private void checkCsvEscapeWriter(final String expected, final String value) {
-        try {
-            final StringWriter writer = new StringWriter();
-            StringEscapeUtils.ESCAPE_CSV.translate(value, writer);
-            assertEquals(expected, writer.toString());
-        } catch (final IOException e) {
-            fail("Threw: " + e);
-        }
+    private void checkCsvEscapeWriter(final String expected, final String value) throws IOException {
+        final StringWriter writer = new StringWriter();
+        StringEscapeUtils.ESCAPE_CSV.translate(value, writer);
+        assertEquals(expected, writer.toString());
     }
 
-    private void checkCsvUnescapeWriter(final String expected, final String value) {
-        try {
-            final StringWriter writer = new StringWriter();
-            StringEscapeUtils.UNESCAPE_CSV.translate(value, writer);
-            assertEquals(expected, writer.toString());
-        } catch (final IOException e) {
-            fail("Threw: " + e);
-        }
+    private void checkCsvUnescapeWriter(final String expected, final String value) throws IOException {
+        final StringWriter writer = new StringWriter();
+        StringEscapeUtils.UNESCAPE_CSV.translate(value, writer);
+        assertEquals(expected, writer.toString());
     }
 
     @Test
-    public void testBuilder() {
-        final String result =
-                StringEscapeUtils.builder(StringEscapeUtils.ESCAPE_XML10).escape("<").append(">").toString();
+    void testBuilder() {
+        final String result = StringEscapeUtils.builder(StringEscapeUtils.ESCAPE_XML10).escape("<").append(">").toString();
         assertEquals("&lt;>", result);
     }
 
     @Test
-    public void testConstructor() {
+    void testConstructor() {
         assertNotNull(new StringEscapeUtils());
         final Constructor<?>[] cons = StringEscapeUtils.class.getDeclaredConstructors();
         assertEquals(1, cons.length);
@@ -132,16 +120,15 @@ public class StringEscapeUtilsTest {
         assertFalse(Modifier.isFinal(StringEscapeUtils.class.getModifiers()));
     }
 
-
     // HTML and XML
     @Test
-    public void testDeleteCharacter() {
-      final String deleteString = "Delete: \u007F";
-      assertEquals("Delete: \\u007F", StringEscapeUtils.escapeJson(deleteString));
+    void testDeleteCharacter() {
+        final String deleteString = "Delete: \u007F";
+        assertEquals("Delete: \\u007F", StringEscapeUtils.escapeJson(deleteString));
     }
 
     @Test
-    public void testEscapeCsvString() {
+    void testEscapeCsvString() {
         assertEquals("foo.bar", StringEscapeUtils.escapeCsv("foo.bar"));
         assertEquals("\"foo,bar\"", StringEscapeUtils.escapeCsv("foo,bar"));
         assertEquals("\"foo\nbar\"", StringEscapeUtils.escapeCsv("foo\nbar"));
@@ -153,7 +140,7 @@ public class StringEscapeUtilsTest {
     }
 
     @Test
-    public void testEscapeCsvWriter() {
+    void testEscapeCsvWriter() throws IOException {
         checkCsvEscapeWriter("foo.bar", "foo.bar");
         checkCsvEscapeWriter("\"foo,bar\"", "foo,bar");
         checkCsvEscapeWriter("\"foo\nbar\"", "foo\nbar");
@@ -164,42 +151,40 @@ public class StringEscapeUtilsTest {
         checkCsvEscapeWriter("", "");
     }
 
-@Test
-public void testEscapeEcmaScript() {
-    assertNull(StringEscapeUtils.escapeEcmaScript(null));
-    try {
-        StringEscapeUtils.ESCAPE_ECMASCRIPT.translate(null, null);
-        fail("Exception expected!");
-    } catch (final IOException ex) {
-        fail("Exception expected!");
-    } catch (final IllegalArgumentException ex) {
-        // expected
-    }
-    try {
-        StringEscapeUtils.ESCAPE_ECMASCRIPT.translate("", null);
-        fail("Exception expected!");
-    } catch (final IOException ex) {
-        fail("Exception expected!");
-    } catch (final IllegalArgumentException ex) {
-        // expected
-    }
+    @Test
+    void testEscapeEcmaScript() {
+        assertNull(StringEscapeUtils.escapeEcmaScript(null));
+        try {
+            StringEscapeUtils.ESCAPE_ECMASCRIPT.translate(null, null);
+            fail("Exception expected!");
+        } catch (final IOException ex) {
+            fail("Exception expected!");
+        } catch (final IllegalArgumentException ex) {
+            // expected
+        }
+        try {
+            StringEscapeUtils.ESCAPE_ECMASCRIPT.translate("", null);
+            fail("Exception expected!");
+        } catch (final IOException ex) {
+            fail("Exception expected!");
+        } catch (final IllegalArgumentException ex) {
+            // expected
+        }
 
-    assertEquals("He didn\\'t say, \\\"stop!\\\"", StringEscapeUtils.escapeEcmaScript("He didn't say, \"stop!\""));
-    assertEquals("document.getElementById(\\\"test\\\").value = \\'<script>alert(\\'aaa\\');<\\/script>\\';",
-            StringEscapeUtils.escapeEcmaScript(
-                    "document.getElementById(\"test\").value = '<script>alert('aaa');</script>';"));
-}
+        assertEquals("He didn\\'t say, \\\"stop!\\\"", StringEscapeUtils.escapeEcmaScript("He didn't say, \"stop!\""));
+        assertEquals("document.getElementById(\\\"test\\\").value = \\'<script>alert(\\'aaa\\');<\\/script>\\';",
+                StringEscapeUtils.escapeEcmaScript("document.getElementById(\"test\").value = '<script>alert('aaa');</script>';"));
+    }
 
     /**
      * Tests https://issues.apache.org/jira/browse/LANG-339
      */
     @Test
-    public void testEscapeHiragana() {
+    void testEscapeHiragana() {
         // Some random Japanese Unicode characters
         final String original = "\u304B\u304C\u3068";
         final String escaped = StringEscapeUtils.escapeHtml4(original);
-        assertEquals(original, escaped,
-                "Hiragana character Unicode behavior should not be being escaped by escapeHtml4");
+        assertEquals(original, escaped, "Hiragana character Unicode behavior should not be being escaped by escapeHtml4");
 
         final String unescaped = StringEscapeUtils.unescapeHtml4(escaped);
 
@@ -207,7 +192,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testEscapeHtml3() {
+    void testEscapeHtml3() {
         for (final String[] element : HTML_ESCAPES) {
             final String message = element[0];
             final String expected = element[1];
@@ -225,33 +210,33 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-        public void testEscapeHtml4() {
-            for (final String[] element : HTML_ESCAPES) {
-                final String message = element[0];
-                final String expected = element[1];
-                final String original = element[2];
-                assertEquals(expected, StringEscapeUtils.escapeHtml4(original), message);
-                final StringWriter sw = new StringWriter();
-                try {
-                    StringEscapeUtils.ESCAPE_HTML4.translate(original, sw);
-                } catch (final IOException e) {
-                    // expected
-                }
-                final String actual = original == null ? null : sw.toString();
-                assertEquals(expected, actual, message);
+    void testEscapeHtml4() {
+        for (final String[] element : HTML_ESCAPES) {
+            final String message = element[0];
+            final String expected = element[1];
+            final String original = element[2];
+            assertEquals(expected, StringEscapeUtils.escapeHtml4(original), message);
+            final StringWriter sw = new StringWriter();
+            try {
+                StringEscapeUtils.ESCAPE_HTML4.translate(original, sw);
+            } catch (final IOException e) {
+                // expected
             }
+            final String actual = original == null ? null : sw.toString();
+            assertEquals(expected, actual, message);
         }
+    }
 
     /**
      * Tests // https://issues.apache.org/jira/browse/LANG-480
      */
     @Test
-    public void testEscapeHtmlHighUnicode() {
+    void testEscapeHtmlHighUnicode() {
         // this is the utf8 representation of the character:
         // COUNTING ROD UNIT DIGIT THREE
         // in Unicode
         // code point: U+1D362
-        final byte[] data = {(byte) 0xF0, (byte) 0x9D, (byte) 0x8D, (byte) 0xA2};
+        final byte[] data = { (byte) 0xF0, (byte) 0x9D, (byte) 0x8D, (byte) 0xA2 };
 
         final String original = new String(data, StandardCharsets.UTF_8);
 
@@ -262,21 +247,19 @@ public void testEscapeEcmaScript() {
         assertEquals(original, unescaped, "High Unicode should have been unchanged");
 
         // TODO: I think this should hold, needs further investigation
-        //        String unescapedFromEntity = StringEscapeUtils.unescapeHtml4("&#119650;");
-        //        assertEquals("High Unicode should have been unescaped", original, unescapedFromEntity);
+        // String unescapedFromEntity = StringEscapeUtils.unescapeHtml4("&#119650;");
+        // assertEquals("High Unicode should have been unescaped", original, unescapedFromEntity);
     }
 
-
-
     @Test
-    public void testEscapeHtmlThree() {
+    void testEscapeHtmlThree() {
         assertNull(StringEscapeUtils.escapeHtml3(null));
         assertEquals("a", StringEscapeUtils.escapeHtml3("a"));
         assertEquals("&lt;b&gt;a", StringEscapeUtils.escapeHtml3("<b>a"));
     }
 
     @Test
-    public void testEscapeHtmlVersions() {
+    void testEscapeHtmlVersions() {
         assertEquals("&Beta;", StringEscapeUtils.escapeHtml4("\u0392"));
         assertEquals("\u0392", StringEscapeUtils.unescapeHtml4("&Beta;"));
 
@@ -284,7 +267,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testEscapeJava() throws IOException {
+    void testEscapeJava() throws IOException {
         assertNull(StringEscapeUtils.escapeJava(null));
         try {
             StringEscapeUtils.ESCAPE_JAVA.translate(null, null);
@@ -315,32 +298,28 @@ public void testEscapeEcmaScript() {
         assertEscapeJava("\\u0001", "\u0001");
         assertEscapeJava("\\uABCD", "\uabcd", "Should use capitalized Unicode hex");
 
-        assertEscapeJava("He didn't say, \\\"stop!\\\"",
-                "He didn't say, \"stop!\"");
-        assertEscapeJava("This space is non-breaking:" + "\\u00A0", "This space is non-breaking:\u00a0",
-                "non-breaking space");
-        assertEscapeJava("\\uABCD\\u1234\\u012C",
-                "\uABCD\u1234\u012C");
+        assertEscapeJava("He didn't say, \\\"stop!\\\"", "He didn't say, \"stop!\"");
+        assertEscapeJava("This space is non-breaking:" + "\\u00A0", "This space is non-breaking:\u00a0", "non-breaking space");
+        assertEscapeJava("\\uABCD\\u1234\\u012C", "\uABCD\u1234\u012C");
     }
 
     /**
      * Tests https://issues.apache.org/jira/browse/LANG-421
      */
     @Test
-    public void testEscapeJavaWithSlash() {
+    void testEscapeJavaWithSlash() {
         final String input = "String with a slash (/) in it";
 
         final String actual = StringEscapeUtils.escapeJava(input);
 
         /*
-         * In 2.4 StringEscapeUtils.escapeJava(String) escapes '/' characters, which are not a valid character
-         * to escape in a Java string.
+         * In 2.4 StringEscapeUtils.escapeJava(String) escapes '/' characters, which are not a valid character to escape in a Java string.
          */
         assertEquals(input, actual);
     }
 
     @Test
-    public void testEscapeJson() {
+    void testEscapeJson() {
         assertNull(StringEscapeUtils.escapeJson(null));
         try {
             StringEscapeUtils.ESCAPE_JSON.translate(null, null);
@@ -368,42 +347,32 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testEscapeXml10() {
+    void testEscapeXml10() {
         assertEquals("a&lt;b&gt;c&quot;d&apos;e&amp;f", StringEscapeUtils.escapeXml10("a<b>c\"d'e&f"));
-        assertEquals("a\tb\rc\nd", StringEscapeUtils.escapeXml10("a\tb\rc\nd"),
-                "XML 1.0 should not escape \t \n \r");
+        assertEquals("a\tb\rc\nd", StringEscapeUtils.escapeXml10("a\tb\rc\nd"), "XML 1.0 should not escape \t \n \r");
         assertEquals("ab", StringEscapeUtils.escapeXml10("a\u0000\u0001\u0008\u000b\u000c\u000e\u001fb"),
                 "XML 1.0 should omit most #x0-x8 | #xb | #xc | #xe-#x19");
-        assertEquals("a\ud7ff  \ue000b", StringEscapeUtils.escapeXml10("a\ud7ff\ud800 \udfff \ue000b"),
-                "XML 1.0 should omit #xd800-#xdfff");
-        assertEquals("a\ufffdb", StringEscapeUtils.escapeXml10("a\ufffd\ufffe\uffffb"),
-                "XML 1.0 should omit #xfffe | #xffff");
-        assertEquals("a\u007e&#127;&#132;\u0085&#134;&#159;\u00a0b",
-                StringEscapeUtils.escapeXml10("a\u007e\u007f\u0084\u0085\u0086\u009f\u00a0b"),
+        assertEquals("a\ud7ff  \ue000b", StringEscapeUtils.escapeXml10("a\ud7ff\ud800 \udfff \ue000b"), "XML 1.0 should omit #xd800-#xdfff");
+        assertEquals("a\ufffdb", StringEscapeUtils.escapeXml10("a\ufffd\ufffe\uffffb"), "XML 1.0 should omit #xfffe | #xffff");
+        assertEquals("a\u007e&#127;&#132;\u0085&#134;&#159;\u00a0b", StringEscapeUtils.escapeXml10("a\u007e\u007f\u0084\u0085\u0086\u009f\u00a0b"),
                 "XML 1.0 should escape #x7f-#x84 | #x86 - #x9f, for XML 1.1 compatibility");
     }
 
     @Test
-    public void testEscapeXml11() {
+    void testEscapeXml11() {
         assertEquals("a&lt;b&gt;c&quot;d&apos;e&amp;f", StringEscapeUtils.escapeXml11("a<b>c\"d'e&f"));
-        assertEquals("a\tb\rc\nd", StringEscapeUtils.escapeXml11("a\tb\rc\nd"),
-                "XML 1.1 should not escape \t \n \r");
-        assertEquals("ab", StringEscapeUtils.escapeXml11("a\u0000b"),
-                "XML 1.1 should omit #x0");
-        assertEquals("a&#1;&#8;&#11;&#12;&#14;&#31;b",
-                StringEscapeUtils.escapeXml11("a\u0001\u0008\u000b\u000c\u000e\u001fb"),
+        assertEquals("a\tb\rc\nd", StringEscapeUtils.escapeXml11("a\tb\rc\nd"), "XML 1.1 should not escape \t \n \r");
+        assertEquals("ab", StringEscapeUtils.escapeXml11("a\u0000b"), "XML 1.1 should omit #x0");
+        assertEquals("a&#1;&#8;&#11;&#12;&#14;&#31;b", StringEscapeUtils.escapeXml11("a\u0001\u0008\u000b\u000c\u000e\u001fb"),
                 "XML 1.1 should escape #x1-x8 | #xb | #xc | #xe-#x19");
-        assertEquals("a\u007e&#127;&#132;\u0085&#134;&#159;\u00a0b",
-                StringEscapeUtils.escapeXml11("a\u007e\u007f\u0084\u0085\u0086\u009f\u00a0b"),
+        assertEquals("a\u007e&#127;&#132;\u0085&#134;&#159;\u00a0b", StringEscapeUtils.escapeXml11("a\u007e\u007f\u0084\u0085\u0086\u009f\u00a0b"),
                 "XML 1.1 should escape #x7F-#x84 | #x86-#x9F");
-        assertEquals("a\ud7ff  \ue000b", StringEscapeUtils.escapeXml11("a\ud7ff\ud800 \udfff \ue000b"),
-                "XML 1.1 should omit #xd800-#xdfff");
-        assertEquals("a\ufffdb", StringEscapeUtils.escapeXml11("a\ufffd\ufffe\uffffb"),
-                "XML 1.1 should omit #xfffe | #xffff");
+        assertEquals("a\ud7ff  \ue000b", StringEscapeUtils.escapeXml11("a\ud7ff\ud800 \udfff \ue000b"), "XML 1.1 should omit #xd800-#xdfff");
+        assertEquals("a\ufffdb", StringEscapeUtils.escapeXml11("a\ufffd\ufffe\uffffb"), "XML 1.1 should omit #xfffe | #xffff");
     }
 
     @Test
-    public void testEscapeXSI() {
+    void testEscapeXSI() {
         assertNull(null, escapeXSI(null));
         assertEquals("He\\ didn\\'t\\ say,\\ \\\"Stop!\\\"", escapeXSI("He didn't say, \"Stop!\""));
         assertEquals("\\\\", escapeXSI("\\"));
@@ -411,18 +380,17 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testLang313() {
+    void testLang313() {
         assertEquals("& &", StringEscapeUtils.unescapeHtml4("& &amp;"));
     }
 
     /**
      * Tests https://issues.apache.org/jira/browse/LANG-708
      *
-     * @throws IOException
-     *             if an I/O error occurs
+     * @throws IOException if an I/O error occurs
      */
     @Test
-    public void testLang708() throws IOException {
+    void testLang708() throws IOException {
         final byte[] inputBytes = Files.readAllBytes(Paths.get("src/test/resources/org/apache/commons/text/stringEscapeUtilsTestData.txt"));
         final String input = new String(inputBytes, StandardCharsets.UTF_8);
         final String escaped = StringEscapeUtils.escapeEcmaScript(input);
@@ -436,7 +404,7 @@ public void testEscapeEcmaScript() {
      * Tests https://issues.apache.org/jira/browse/LANG-911
      */
     @Test
-    public void testLang911() {
+    void testLang911() {
         final String bellsTest = "\ud83d\udc80\ud83d\udd14";
         final String value = StringEscapeUtils.escapeJava(bellsTest);
         final String valueTest = StringEscapeUtils.unescapeJava(value);
@@ -446,7 +414,7 @@ public void testEscapeEcmaScript() {
     // Tests issue #38569
     // https://issues.apache.org/bugzilla/show_bug.cgi?id=38569
     @Test
-    public void testStandaloneAmphersand() {
+    void testStandaloneAmphersand() {
         assertEquals("<P&O>", StringEscapeUtils.unescapeHtml4("&lt;P&O&gt;"));
         assertEquals("test & <", StringEscapeUtils.unescapeHtml4("test & &lt;"));
         assertEquals("<P&O>", StringEscapeUtils.unescapeXml("&lt;P&O&gt;"));
@@ -454,7 +422,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testUnescapeCsvString() {
+    void testUnescapeCsvString() {
         assertEquals("foo.bar", StringEscapeUtils.unescapeCsv("foo.bar"));
         assertEquals("foo,bar", StringEscapeUtils.unescapeCsv("\"foo,bar\""));
         assertEquals("foo\nbar", StringEscapeUtils.unescapeCsv("\"foo\nbar\""));
@@ -468,7 +436,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testUnescapeCsvWriter() {
+    void testUnescapeCsvWriter() throws IOException {
         checkCsvUnescapeWriter("foo.bar", "foo.bar");
         checkCsvUnescapeWriter("foo,bar", "\"foo,bar\"");
         checkCsvUnescapeWriter("foo\nbar", "\"foo\nbar\"");
@@ -482,17 +450,16 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testUnescapeEcmaScript() {
+    void testUnescapeEcmaScript() {
         assertNull(StringEscapeUtils.unescapeEcmaScript(null));
         assertEquals("8lvc1u+6B#-I", StringEscapeUtils.unescapeEcmaScript("8lvc1u+6B#-I"));
-        assertEquals("<script src=\"build/main.bundle.js\"></script>",
-                StringEscapeUtils.unescapeEcmaScript("<script src=\"build/main.bundle.js\"></script>"));
+        assertEquals("<script src=\"build/main.bundle.js\"></script>", StringEscapeUtils.unescapeEcmaScript("<script src=\"build/main.bundle.js\"></script>"));
         assertEquals("<script src=\"build/main.bundle.js\"></script>>",
                 StringEscapeUtils.unescapeEcmaScript("<script src=\"build/main.bundle.js\"></script>>"));
     }
 
     @Test
-    public void testUnescapeHexCharsHtml() {
+    void testUnescapeHexCharsHtml() {
         // Simple easy to grok test
         assertEquals("\u0080\u009F", StringEscapeUtils.unescapeHtml4("&#x80;&#x9F;"), "hex number unescape");
         assertEquals("\u0080\u009F", StringEscapeUtils.unescapeHtml4("&#X80;&#X9F;"), "hex number unescape");
@@ -502,13 +469,12 @@ public void testEscapeEcmaScript() {
             final String expected = Character.toString(i) + Character.toString(c2);
             final String escapedC1 = "&#x" + Integer.toHexString(i) + ";";
             final String escapedC2 = "&#x" + Integer.toHexString(c2) + ";";
-            assertEquals(expected, StringEscapeUtils.unescapeHtml4(escapedC1 + escapedC2),
-                    "hex number unescape index " + i);
+            assertEquals(expected, StringEscapeUtils.unescapeHtml4(escapedC1 + escapedC2), "hex number unescape index " + i);
         }
     }
 
     @Test
-    public void testUnescapeHtml3() {
+    void testUnescapeHtml3() {
         for (final String[] element : HTML_ESCAPES) {
             final String message = element[0];
             final String expected = element[2];
@@ -536,7 +502,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testUnescapeHtml4() {
+    void testUnescapeHtml4() {
         for (final String[] element : HTML_ESCAPES) {
             final String message = element[0];
             final String expected = element[2];
@@ -564,7 +530,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testUnescapeJava() throws IOException {
+    void testUnescapeJava() throws IOException {
         assertNull(StringEscapeUtils.unescapeJava(null));
         try {
             StringEscapeUtils.UNESCAPE_JAVA.translate(null, null);
@@ -590,16 +556,15 @@ public void testEscapeEcmaScript() {
         assertUnescapeJava("\u123425foo\ntest\b", "\\u123425foo\\ntest\\b");
         assertUnescapeJava("'\foo\teste\r", "\\'\\foo\\teste\\r");
         assertUnescapeJava("", "\\");
-        //foo
+        // foo
         assertUnescapeJava("\uABCDx", "\\uabcdx", "lowercase Unicode");
         assertUnescapeJava("\uABCDx", "\\uABCDx", "uppercase Unicode");
         assertUnescapeJava("\uABCD", "\\uabcd", "Unicode as final character");
     }
 
     @Test
-    public void testUnescapeJson() {
-        final String jsonString =
-                "{\"age\":100,\"name\":\"kyong.com\n\",\"messages\":[\"msg 1\",\"msg 2\",\"msg 3\"]}";
+    void testUnescapeJson() {
+        final String jsonString = "{\"age\":100,\"name\":\"kyong.com\n\",\"messages\":[\"msg 1\",\"msg 2\",\"msg 3\"]}";
 
         assertEquals("", StringEscapeUtils.unescapeJson(""));
         assertEquals(" ", StringEscapeUtils.unescapeJson(" "));
@@ -608,15 +573,15 @@ public void testEscapeEcmaScript() {
     }
 
     @Test // TEXT-120
-    public void testUnescapeJsonDoubleQuoteAndForwardSlash() {
-      final String escapedJsonString = "double quote: \\\" and a forward slash: \\/";
-      final String jsonString = "double quote: \" and a forward slash: /";
+    void testUnescapeJsonDoubleQuoteAndForwardSlash() {
+        final String escapedJsonString = "double quote: \\\" and a forward slash: \\/";
+        final String jsonString = "double quote: \" and a forward slash: /";
 
-      assertEquals(jsonString, StringEscapeUtils.unescapeJson(escapedJsonString));
+        assertEquals(jsonString, StringEscapeUtils.unescapeJson(escapedJsonString));
     }
 
     @Test
-    public void testUnescapeUnknownEntity() {
+    void testUnescapeUnknownEntity() {
         assertEquals("&zzzz;", StringEscapeUtils.unescapeHtml4("&zzzz;"));
     }
 
@@ -626,16 +591,15 @@ public void testEscapeEcmaScript() {
      * @see <a href="https://issues.apache.org/jira/browse/LANG-729">LANG-729</a>
      */
     @Test
-    public void testUnescapeXmlSupplementaryCharacters() {
-        assertEquals("\uD84C\uDFB4", StringEscapeUtils.unescapeXml("&#144308;"),
-                "Supplementary character must be represented using a single escape");
+    void testUnescapeXmlSupplementaryCharacters() {
+        assertEquals("\uD84C\uDFB4", StringEscapeUtils.unescapeXml("&#144308;"), "Supplementary character must be represented using a single escape");
 
         assertEquals("a b c \uD84C\uDFB4", StringEscapeUtils.unescapeXml("a b c &#144308;"),
                 "Supplementary characters mixed with basic characters should be decoded correctly");
     }
 
     @Test
-    public void testUnscapeXSI() {
+    void testUnscapeXSI() {
         assertNull(null, unescapeXSI(null));
         assertEquals("\"", unescapeXSI("\\\""));
         assertEquals("He didn't say, \"Stop!\"", unescapeXSI("He\\ didn\\'t\\ say,\\ \\\"Stop!\\\""));
