@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,63 +17,61 @@
 
 package org.apache.commons.text.translate;
 
-import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import org.junit.jupiter.api.Test;
 
 /**
  * Tests {@link NumericEntityUnescaper}.
  */
-public class NumericEntityUnescaperTest  {
+class NumericEntityUnescaperTest  {
 
     @Test
-    public void testCreatesNumericEntityUnescaperOne() {
+    void testCreatesNumericEntityUnescaperOne() {
         final NumericEntityUnescaper.OPTION[] numericEntityUnescaperOPTIONArray = {};
         final NumericEntityUnescaper numericEntityUnescaper =
                 new NumericEntityUnescaper(numericEntityUnescaperOPTIONArray);
-
-        assertThat(numericEntityUnescaper.translate("2|y|O7y`&#uVWj")).isEqualTo("2|y|O7y`&#uVWj");
+        assertEquals("2|y|O7y`&#uVWj", numericEntityUnescaper.translate("2|y|O7y`&#uVWj"));
     }
 
     @Test
-    public void testCreatesNumericEntityUnescaperTwo() {
+    void testCreatesNumericEntityUnescaperTwo() {
         final NumericEntityUnescaper.OPTION[] numericEntityUnescaperOPTIONArray = {};
         final NumericEntityUnescaper numericEntityUnescaper =
                 new NumericEntityUnescaper(numericEntityUnescaperOPTIONArray);
-
-        assertThat(numericEntityUnescaper.translate("Ws2v8|O=7NR&#cB")).isEqualTo("Ws2v8|O=7NR&#cB");
+        assertEquals("Ws2v8|O=7NR&#cB", numericEntityUnescaper.translate("Ws2v8|O=7NR&#cB"));
     }
 
     @Test
-    public void testOutOfBounds() {
+    void testOutOfBounds() {
         final NumericEntityUnescaper neu = new NumericEntityUnescaper();
 
-        assertThat(neu.translate("Test &")).as("Failed to ignore when last character is &").isEqualTo("Test &");
-        assertThat(neu.translate("Test &#")).as("Failed to ignore when last character is &").isEqualTo("Test &#");
-        assertThat(neu.translate("Test &#x")).as("Failed to ignore when last character is &").isEqualTo("Test &#x");
-        assertThat(neu.translate("Test &#X")).as("Failed to ignore when last character is &").isEqualTo("Test &#X");
+        assertEquals("Test &", neu.translate("Test &"), "Failed to ignore when last character is &");
+        assertEquals("Test &#", neu.translate("Test &#"), "Failed to ignore when last character is &");
+        assertEquals("Test &#x", neu.translate("Test &#x"), "Failed to ignore when last character is &");
+        assertEquals("Test &#X", neu.translate("Test &#X"), "Failed to ignore when last character is &");
     }
 
     @Test
-    public void testSupplementaryUnescaping() {
+    void testSupplementaryUnescaping() {
         final NumericEntityUnescaper neu = new NumericEntityUnescaper();
         final String input = "&#68642;";
         final String expected = "\uD803\uDC22";
 
         final String result = neu.translate(input);
-        assertThat(result).as("Failed to unescape numeric entities supplementary characters").isEqualTo(expected);
+        assertEquals(expected, result, "Failed to unescape numeric entities supplementary characters");
     }
 
     @Test
-    public void testUnfinishedEntity() {
+    void testUnfinishedEntity() {
         // parse it
         NumericEntityUnescaper neu = new NumericEntityUnescaper(NumericEntityUnescaper.OPTION.semiColonOptional);
         String input = "Test &#x30 not test";
         String expected = "Test \u0030 not test";
 
         String result = neu.translate(input);
-        assertThat(result).as("Failed to support unfinished entities (i.e. missing semicolon)").isEqualTo(expected);
+        assertEquals(expected, result, "Failed to support unfinished entities (i.e. missing semicolon)");
 
         // ignore it
         neu = new NumericEntityUnescaper();
@@ -81,7 +79,7 @@ public class NumericEntityUnescaperTest  {
         expected = input;
 
         result = neu.translate(input);
-        assertThat(result).as("Failed to ignore unfinished entities (i.e. missing semicolon)").isEqualTo(expected);
+        assertEquals(expected, result, "Failed to ignore unfinished entities (i.e. missing semicolon)");
 
         // fail it
         neu = new NumericEntityUnescaper(NumericEntityUnescaper.OPTION.errorIfNoSemiColon);
